@@ -1,6 +1,6 @@
-#  ATContentTypes http://sf.net/projects/collective/
+#  ATContentTypes http://plone.org/products/atcontenttypes/
 #  Archetypes reimplementation of the CMF core types
-#  Copyright (c) 2003-2005 AT Content Types development team
+#  Copyright (c) 2003-2006 AT Content Types development team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,12 +19,14 @@
 """
 
 """
-__author__  = 'Christian Heimes <ch@comlounge.net>'
+__author__  = 'Christian Heimes <tiran@cheimes.de>'
 __docformat__ = 'restructuredtext'
 
 
+import posixpath
 from copy import copy
 import logging
+import transaction
 
 from Products.ATContentTypes.config import HAS_LINGUA_PLONE
 if HAS_LINGUA_PLONE:
@@ -54,7 +56,6 @@ from webdav.NullResource import NullResource
 from zExceptions import MethodNotAllowed
 from zExceptions import NotFound
 from ZODB.POSException import ConflictError
-from Products.CMFPlone import transaction
 
 from Products.CMFCore.permissions import View
 from Products.CMFCore.permissions import ModifyPortalContent
@@ -131,7 +132,7 @@ def cleanupFilename(filename, context=None, encoding='utf-8'):
     if context is not None:
         plone_utils = getToolByName(context, 'plone_utils', None)
         if plone_utils is not None:
-            return plone_utils.normalizeString(filename)
+            return plone_utils.normalizeString(filename, relaxed=True)
 
     # no context or plone_utils
     result = u''
@@ -234,10 +235,9 @@ class ATCTMixin(BrowserDefaultMixin):
                 raise
                 #_default_logger.log_exc()
 
-    security.declarePrivate('copyDefaultViewFromParent')
+    security.declarePrivate('copyLayoutFromParent')
     def copyLayoutFromParent(self):
-        """ A method to copy the layout from the parent object if it is of the
-            same type. """
+        """Copies the layout from the parent object if it's of the same type."""
         parent = aq_parent(aq_inner(self))
         if parent is not None:
             # Only set the layout if we are the same type as out parent object
@@ -327,9 +327,30 @@ class ATCTContent(ATCTMixin, BaseContent):
 
         Set title according to the id on webdav/ftp PUTs.
         """
+        id = self.getId()
         title = self.Title()
         if not title:
-            self.setTitle(self.getId())
+            # Use the last-segment from the url as the id, as the
+            # object might have been renamed somehow (eg: by id
+            # mangling).
+            request = REQUEST or getattr(self, 'REQUEST', None)
+            if request is not None:
+                path_info = request.get('PATH_INFO')
+                if path_info:
+                    id = posixpath.basename(path_info)
+            self.setTitle(id)
+
+    #def PUT(self, *args, **kwargs):
+    #    """Overwrite PUT to delete ignored content after it is created
+    #    """
+    #    created = getattr(self, ' __null_resource__', False)
+    #    result = BaseContent.PUT(self, *args, **kwargs)
+    #    if created and self._PUT_ignorematch(self):
+    #        parent = getattr(self, '__parent__', None)
+    #        name = getattr(self, '__name__', None)
+    #        if parent is not None or name is not None:
+    #            parent.manage_delObjects([name])
+    #    return result
 
 InitializeClass(ATCTContent)
 
@@ -481,7 +502,7 @@ class ATCTFileContent(ATCTContent):
                 # got a clean file name - rename it
                 # apply subtransaction. w/o a subtransaction renaming
                 # fails when the type is created using portal_factory
-                transaction.commit(1)
+                transaction.savepoint(optimistic=True)
                 self.setId(clean_filename)
 
     security.declareProtected(View, 'post_validate')
@@ -525,12 +546,21 @@ class ATCTFileContent(ATCTContent):
         Set the title according to the uploaded filename if the title
         is empty or set it to the id if no filename is given.
         """
+        id = self.getId()
         title = self.Title()
         if not title:
             if filename:
                 self.setTitle(filename)
             else:
-                self.setTitle(self.getId())
+                # Use the last-segment from the url as the id, as the
+                # object might have been renamed somehow (eg: by id
+                # mangling).
+                request = REQUEST or getattr(self, 'REQUEST', None)
+                if request is not None:
+                    path_info = request.get('PATH_INFO')
+                    if path_info:
+                        id = posixpath.basename(path_info)
+                self.setTitle(id)
 
 InitializeClass(ATCTFileContent)
 
@@ -606,6 +636,14 @@ class ATCTFolderMixin(ConstrainTypesMixin, ATCTMixin):
         new = getattr(self, id)
         title = new.Title()
         if not title.strip():
+            # Use the last-segment from the url as the id, as the
+            # object might have been renamed somehow (eg: by id
+            # mangling).
+            request = REQUEST or getattr(self, 'REQUEST', None)
+            if request is not None:
+                path_info = request.get('PATH_INFO')
+                if path_info:
+                    id = posixpath.basename(path_info)
             new.update(title=id)
 
     security.declareProtected(View, 'HEAD')
