@@ -1,6 +1,6 @@
-#  ATContentTypes http://sf.net/projects/collective/
+#  ATContentTypes http://plone.org/products/atcontenttypes/
 #  Archetypes reimplementation of the CMF core types
-#  Copyright (c) 2003-2005 AT Content Types development team
+#  Copyright (c) 2003-2006 AT Content Types development team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 
 """
-__author__  = 'Christian Heimes <ch@comlounge.net>, Alec Mitchell'
+__author__  = 'Christian Heimes <tiran@cheimes.de>, Alec Mitchell'
 __docformat__ = 'restructuredtext'
 __old_name__ = 'Products.ATContentTypes.types.ATTopic'
 
@@ -463,7 +463,7 @@ class ATTopic(ATCTFolder):
         if max_items and b_size is None:
             b_size = int(max_items)
         else:
-            b_size = 20
+            b_size = b_size or 20
         if not batch and limit and max_items and self.hasSortCriterion():
             # Sort limit helps Zope 2.6.1+ to do a faster query
             # sorting when sort is involved
@@ -538,7 +538,7 @@ class ATTopic(ATCTFolder):
         """
         return False
 
-    security.declarePublic('getCriterionUniqueWidgetAttributes')
+    security.declarePublic('getCriterionUniqueWidgetAttr')
     def getCriteriaUniqueWidgetAttr(self, attr):
         """Get a unique list values for a specific attribute for all widgets
            on all criteria"""
