@@ -56,3 +56,33 @@ def registerMigrations():
     atct.registerUpgradePath('1.0.2-final',
                              '1.0.3-final',
                              null)
+    atct.registerUpgradePath('1.0.3-final',
+                             '1.0.4-final',
+                             null)
+    atct.registerUpgradePath('1.0.4-final',
+                             '1.0.5-final',
+                             null)
+    atct.registerUpgradePath('1.0.5-final',
+                             '1.1.0-alpha1',
+                             null)
+    atct.registerUpgradePath('1.1.0-alpha1',
+                             '1.1.0-alpha2',
+                             null)
+    atct.registerUpgradePath('1.1.0-alpha2',
+                             '1.1.0-beta1',
+                             null)
+    atct.registerUpgradePath('1.1.0-beta1',
+                             '1.1.0-beta2',
+                             null)
+    atct.registerUpgradePath('1.1.0-beta2',
+                             '1.1.0-final',
+                             null)
+    atct.registerUpgradePath('1.1.0-final',
+                             '1.1.1-final',
+                             null)
+    atct.registerUpgradePath('1.1.1-final',
+                             '1.1.2-final',
+                             null)
+    atct.registerUpgradePath('1.1.2-final',
+                             '1.1.3-final',
+                             null)
