@@ -1,9 +1,9 @@
 """Migration tools for ATContentTypes
 
 Migration system for the migration from CMFDefault/Event types to archetypes
-based CMFPloneTypes (http://sf.net/projects/collective/).
+based CMFPloneTypes (http://plone.org/products/atcontenttypes/).
 
-Copyright (c) 2004-2005, Christian Heimes <ch@comlounge.net> and contributors
+Copyright (c) 2004-2005, Christian Heimes <tiran@cheimes.de> and contributors
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification,
@@ -18,7 +18,7 @@ are permitted provided that the following conditions are met:
    to endorse or promote products derived from this software without specific
    prior written permission.
 """
-__author__  = 'Christian Heimes <ch@comlounge.net>'
+__author__  = 'Christian Heimes <tiran@cheimes.de>'
 __docformat__ = 'restructuredtext'
 
 from copy import copy
@@ -552,7 +552,7 @@ class UIDMigrator:
             return # no uid handler available
         uid = uidhandler.queryUid(self.old, default=None)
         if uid is not None:
-            uidhandler._setUid(self.new, uid)
+            uidhandler.setUid(self.new, uid, check_uniqueness=False)
             
     def migrate_at_uuid(self):
         """Migrate AT universal uid
