@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-#  ATContentTypes http://sf.net/projects/collective/
+#  ATContentTypes http://plone.org/products/atcontenttypes/
 #  Archetypes reimplementation of the CMF core types
-#  Copyright (c) 2003-2005 AT Content Types development team
+#  Copyright (c) 2003-2006 AT Content Types development team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 """
 """
 
-__author__ = 'Christian Heimes <ch@comlounge.net>'
+__author__ = 'Christian Heimes <tiran@cheimes.de>'
 __docformat__ = 'restructuredtext'
 
 import os, sys
@@ -29,14 +29,14 @@ if __name__ == '__main__':
 
 import unittest
 from Testing import ZopeTestCase # side effect import. leave it here.
-from Products.ATContentTypes.tests import atcttestcase
+from Products.ATContentTypes.tests import atcttestcase, atctftestcase
 
+import time, transaction
 from Products.CMFCore.permissions import View
 from Products.CMFCore.permissions import ModifyPortalContent
 from Products.Archetypes.interfaces.layer import ILayerContainer
 from Products.Archetypes.public import *
 from Products.ATContentTypes.tests.utils import dcEdit
-import time
 import StringIO
 
 from Products.ATContentTypes.content.file import ATFile
@@ -45,7 +45,12 @@ from Products.ATContentTypes.interfaces import IATFile
 from Products.ATContentTypes.interfaces import IFileContent
 from Products.CMFDefault.File import File
 from Interface.Verify import verifyObject
-from Products.CMFPlone import transaction
+
+# z3 imports
+from Products.ATContentTypes.interface import IATFile as Z3IATFile
+from Products.ATContentTypes.interface import IFileContent as Z3IFileContent
+from zope.interface.verify import verifyObject as Z3verifyObject
+
 
 file_text = """
 foooooo
@@ -76,11 +81,19 @@ class TestSiteATFile(atcttestcase.ATCTTypeTestCase):
         self.failUnless(iface.isImplementedBy(self._ATCT))
         self.failUnless(verifyObject(iface, self._ATCT))
 
+    def test_implementsZ3FileContent(self):
+        iface = Z3IFileContent
+        self.failUnless(Z3verifyObject(iface, self._ATCT))
+
     def test_implementsATFile(self):
         iface = IATFile
         self.failUnless(iface.isImplementedBy(self._ATCT))
         self.failUnless(verifyObject(iface, self._ATCT))
 
+    def test_implementsZ3ATFile(self):
+        iface = Z3IATFile
+        self.failUnless(Z3verifyObject(iface, self._ATCT))
+
     def test_edit(self):
         old = self._cmf
         new = self._ATCT
@@ -119,7 +132,7 @@ class TestSiteATFile(atcttestcase.ATCTTypeTestCase):
         time.sleep(1.5)
 
         # migrated (needs subtransaction to work)
-        transaction.commit(1)
+        transaction.savepoint(optimistic=True)
         m = FileMigrator(old)
         m(unittest=1)
 
@@ -157,6 +170,27 @@ class TestSiteATFile(atcttestcase.ATCTTypeTestCase):
                                        file=fakefile)
         self.assertEquals(id, fakefile.filename)
 
+    def testUpperCaseFilename(self):
+        class fakefile(StringIO.StringIO):
+            pass
+        fakefile = fakefile()
+        fakefile.filename = 'Some_filename_With_Uppercase.txt'
+        id = 'file.2005-11-18.4066860573'
+        self.folder.invokeFactory(self.portal_type, id)
+        self.folder[id].setFile(fakefile)
+        self.failIf(id in self.folder.objectIds())
+        self.failUnless(fakefile.filename in self.folder.objectIds())
+
+    def testUpperCaseFilenameWithFunnyCharacters(self):
+        class fakefile(StringIO.StringIO):
+            pass
+        fakefile = fakefile()
+        fakefile.filename = 'Zope&Plo?ne .txt'
+        id = 'file.2005-11-18.4066860574'
+        self.folder.invokeFactory(self.portal_type, id)
+        self.folder[id].setFile(fakefile)
+        self.failIf(id in self.folder.objectIds())
+        self.failUnless('Zope-Plo-ne .txt' in self.folder.objectIds())
 
 tests.append(TestSiteATFile)
 
@@ -219,6 +253,58 @@ class TestCleanupFilename(unittest.TestCase):
 
 tests.append(TestCleanupFilename)
 
+class TestATFileFunctional(atctftestcase.ATCTIntegrationTestCase):
+    
+    portal_type = 'File'
+    views = ('file_view', 'download', )
+
+    def test_inlineMimetypes_Office(self):
+        # Only PDF and Office docs are shown inline
+        self.obj.setFormat('application/msword')
+        response = self.publish(self.obj_path)
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Content-Disposition'), None)
+
+        self.obj.setFormat('application/x-msexcel')
+        response = self.publish(self.obj_path)
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Content-Disposition'), None)
+
+        self.obj.setFormat('application/vnd.ms-excel')
+        response = self.publish(self.obj_path)
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Content-Disposition'), None)
+
+        self.obj.setFormat('application/vnd.ms-powerpoint')
+        response = self.publish(self.obj_path)
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Content-Disposition'), None)
+
+    def test_inlineMimetypes_PDF(self):
+        # Only PDF and Office docs are shown inline
+        self.obj.setFormat('application/pdf')
+        response = self.publish(self.obj_path)
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Content-Disposition'), None)
+
+    def test_inlineMimetypes_Text(self):
+        # Only PDF and Office docs are shown inline
+        self.obj.setFilename('foo.txt')
+        self.obj.setFormat('text/plain')
+        response = self.publish(self.obj_path)
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Content-Disposition'), 'attachment; filename="foo.txt"')
+
+    def test_inlineMimetypes_Binary(self):
+        # Only PDF and Office docs are shown inline
+        self.obj.setFilename('foo.exe')
+        self.obj.setFormat('application/octet-stream')
+        response = self.publish(self.obj_path)
+        self.assertEqual(response.getStatus(), 200)
+        self.assertEqual(response.getHeader('Content-Disposition'), 'attachment; filename="foo.exe"')
+
+tests.append(TestATFileFunctional)
+
 
 if __name__ == '__main__':
     framework()
