@@ -1,6 +1,6 @@
-#  ATContentTypes http://sf.net/projects/collective/
+#  ATContentTypes http://plone.org/products/atcontenttypes/
 #  Archetypes reimplementation of the CMF core types
-#  Copyright (c) 2003-2005 AT Content Types development team
+#  Copyright (c) 2003-2006 AT Content Types development team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 """
 """
 
-__author__ = 'Christian Heimes <ch@comlounge.net>'
+__author__ = 'Christian Heimes <tiran@cheimes.de>'
 __docformat__ = 'restructuredtext'
 
 import os, sys
@@ -27,8 +27,9 @@ if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
 from Testing import ZopeTestCase # side effect import. leave it here.
-from Products.ATContentTypes.tests import atcttestcase
+from Products.ATContentTypes.tests import atcttestcase, atctftestcase
 
+import transaction
 from Products.CMFCore.permissions import View
 from Products.CMFCore.permissions import ModifyPortalContent
 from Products.Archetypes.interfaces.layer import ILayerContainer
@@ -39,8 +40,10 @@ from Products.ATContentTypes.migration.atctmigrator import LinkMigrator
 from Products.ATContentTypes.interfaces import IATLink
 from Products.CMFDefault.Link import Link
 from Interface.Verify import verifyObject
-from Products.CMFPlone import transaction
 
+# z3 imports
+from Products.ATContentTypes.interface import IATLink as Z3IATLink
+from zope.interface.verify import verifyObject as Z3verifyObject
 
 URL='http://www.example.org/'
 
@@ -71,6 +74,10 @@ class TestSiteATLink(atcttestcase.ATCTTypeTestCase):
         self.failUnless(iface.isImplementedBy(self._ATCT))
         self.failUnless(verifyObject(iface, self._ATCT))
 
+    def test_implementsATLink(self):
+        iface = Z3IATLink
+        self.failUnless(Z3verifyObject(iface, self._ATCT))
+
     def testLink(self):
         obj = self._ATCT
 
@@ -106,7 +113,7 @@ class TestSiteATLink(atcttestcase.ATCTTypeTestCase):
 
 
         # migrated (needs subtransaction to work)
-        transaction.commit(1)
+        transaction.savepoint(optimistic=True)
         m = LinkMigrator(old)
         m()
 
@@ -178,6 +185,14 @@ class TestATLinkFields(atcttestcase.ATCTFieldTestCase):
 
 tests.append(TestATLinkFields)
 
+class TestATLinkFunctional(atctftestcase.ATCTIntegrationTestCase):
+    
+    portal_type = 'Link'
+    views = ('link_view', )
+
+tests.append(TestATLinkFunctional)
+
+
 if __name__ == '__main__':
     framework()
 else:
