@@ -1,6 +1,6 @@
-#  ATContentTypes http://sf.net/projects/collective/
+#  ATContentTypes http://plone.org/products/atcontenttypes/
 #  Archetypes reimplementation of the CMF core types
-#  Copyright (c) 2003-2005 AT Content Types development team
+#  Copyright (c) 2003-2006 AT Content Types development team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -27,9 +27,10 @@ if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
 from Testing import ZopeTestCase # side effect import. leave it here.
-from Products.ATContentTypes.tests import atcttestcase
+from Products.ATContentTypes.tests import atcttestcase, atctftestcase
 from Products.ATContentTypes.tests.utils import dcEdit
 
+import transaction
 from Products.CMFCore.permissions import View
 from Products.Archetypes.interfaces.layer import ILayerContainer
 from Products.Archetypes.public import *
@@ -44,10 +45,13 @@ from Products.ATContentTypes.migration.atctmigrator import CRIT_MAP, REV_CRIT_MA
 from Products.ATContentTypes.interfaces import IATTopic
 from Interface.Verify import verifyObject
 from OFS.IOrderSupport import IOrderedContainer as IZopeOrderedContainer
-from Products.CMFPlone import transaction
 
 from Products.CMFPlone.PloneBatch import Batch
 
+# z3 imports
+from Products.ATContentTypes.interface import IATTopic as Z3IATTopic
+from zope.interface.verify import verifyObject as Z3verifyObject
+
 
 ACQUIRE  = True
 LIMIT    = False
@@ -114,7 +118,7 @@ def editATCT(obj):
         if CRIT_TYPE == 'ATSimpleIntCriterion':
             value = params[0].split(' ')
             crit.setValue(value[0])
-            if len(value) > 1: 
+            if len(value) > 1:
                 crit.setValue2(value[1])
             crit.setDirection(params[1])
         if CRIT_TYPE == 'ATSortCriterion':
@@ -168,7 +172,7 @@ class TestSiteATTopic(atcttestcase.ATCTTypeTestCase):
     title = 'Smart Folder'
     meta_type = 'ATTopic'
     icon = 'topic_icon.gif'
-    
+
     def afterSetUp(self):
         self.setRoles(['Manager', 'Member'])
         self._ATCT = self._createType(self.folder, self.portal_type, 'ATCT')
@@ -179,7 +183,11 @@ class TestSiteATTopic(atcttestcase.ATCTTypeTestCase):
         iface = IATTopic
         self.failUnless(iface.isImplementedBy(self._ATCT))
         self.failUnless(verifyObject(iface, self._ATCT))
-        
+
+    def test_Z3implementsATTopic(self):
+        iface = Z3IATTopic
+        self.failUnless(Z3verifyObject(iface, self._ATCT))
+
     def test_isNotOrdered(self):
         iface = IZopeOrderedContainer
         self.failIf(iface.isImplementedBy(self._ATCT))
@@ -231,7 +239,7 @@ class TestSiteATTopic(atcttestcase.ATCTTypeTestCase):
         subtopic = topic.qux
 
         subtopic.setAcquireCriteria(True)
-        
+
         #Ensure an empty subtopic uses it's parents' queries
         self.failUnlessEqual(subtopic.buildQuery(), topic.buildQuery())
 
@@ -295,10 +303,10 @@ class TestSiteATTopic(atcttestcase.ATCTTypeTestCase):
         old_query = convert_old_catalog_query(old.buildQuery())
 
         # migrated (needs subtransaction to work)
-        transaction.commit(1)
+        transaction.savepoint(optimistic=True)
         m = TopicMigrator(old)
         m(unittest=1)
-        
+
         self.failUnless(id in self.folder.objectIds(), self.folder.objectIds())
         migrated = getattr(self.folder, id)
 
@@ -386,6 +394,18 @@ class TestSiteATTopic(atcttestcase.ATCTTypeTestCase):
         # Check the batch length
         self.assertEqual(len(topic.queryCatalog(batch=True)), 10)
 
+    def test_queryCatalogBSizeChangesBatchSize(self):
+        #Ensure that a set limit overrides batch size
+        topic = self._ATCT
+        crit = topic.addCriterion('portal_type', 'ATSimpleStringCriterion')
+        crit.setValue('Folder')
+        # Add a bunch of folders.
+        for i in range(1, 20):
+            self.folder.invokeFactory('Folder', str(i))
+        self.failUnless(isinstance(topic.queryCatalog(batch=True, b_size=5),Batch))
+        # Check the batch length
+        self.assertEqual(len(topic.queryCatalog(batch=True, b_size=5)), 5)
+
     def test_get_size(self):
         atct = self._ATCT
         self.failUnlessEqual(atct.get_size(), 1)
@@ -611,6 +631,24 @@ class TestATTopicFields(atcttestcase.ATCTFieldTestCase):
 
 tests.append(TestATTopicFields)
 
+class TestATTopicFunctional(atctftestcase.ATCTIntegrationTestCase):
+
+    def afterSetUp(self):
+        # adding topics is restricted
+        self.setRoles(['Manager', 'Member',])
+        atctftestcase.ATCTIntegrationTestCase.afterSetUp(self)
+
+    def test_dynamic_view_without_view(self):
+        # dynamic view magic should work
+        response = self.publish('%s/' % self.obj_path, self.basic_auth)
+        self.assertStatusEqual(response.getStatus(), 200) #
+
+    portal_type = 'Topic'
+    views = ('atct_topic_view', 'criterion_edit_form', 'atct_topic_subtopics')
+
+tests.append(TestATTopicFunctional)
+
+
 if __name__ == '__main__':
     framework()
 else:
