@@ -1,6 +1,6 @@
-#  ATContentTypes http://sf.net/projects/collective/
+#  ATContentTypes http://plone.org/products/atcontenttypes/
 #  Archetypes reimplementation of the CMF core types
-#  Copyright (c) 2003-2005 AT Content Types development team
+#  Copyright (c) 2003-2006 AT Content Types development team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 """
 """
 
-__author__ = 'Christian Heimes <ch@comlounge.net>'
+__author__ = 'Christian Heimes <tiran@cheimes.de>'
 __docformat__ = 'restructuredtext'
 
 import os, sys
@@ -57,6 +57,10 @@ from Products.ATContentTypes.criteria.currentauthor import \
 from Products.ATContentTypes.criteria.path import ATPathCriterion
 tests = []
 
+# z3 imports
+from Products.ATContentTypes.interface import IATTopicCriterion as Z3IATTopicCriterion
+from zope.interface.verify import verifyObject as Z3verifyObject
+
 class CriteriaTest(atcttestcase.ATCTSiteTestCase):
 
     klass = None
@@ -124,7 +128,11 @@ class CriteriaTest(atcttestcase.ATCTSiteTestCase):
             self.failUnless(IATTopicCriterion.isImplementedBy(self.dummy))
             self.failUnless(verifyObject(IBaseContent, self.dummy))
             self.failUnless(verifyObject(IATTopicCriterion, self.dummy))
-        
+
+    def test_Z3implements(self):
+        if self.dummy is not None:
+            iface = Z3IATTopicCriterion
+            self.failUnless(Z3verifyObject(iface, self.dummy))
 
 class TestATBaseCriterion(CriteriaTest):
     klass = ATBaseCriterion
