@@ -1,6 +1,6 @@
-#  ATContentTypes http://sf.net/projects/collective/
+#  ATContentTypes http://plone.org/products/atcontenttypes/
 #  Archetypes reimplementation of the CMF core types
-#  Copyright (c) 2003-2005 AT Content Types development team
+#  Copyright (c) 2003-2006 AT Content Types development team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 """
 """
 
-__author__ = 'Christian Heimes <ch@comlounge.net>'
+__author__ = 'Christian Heimes <tiran@cheimes.de>'
 __docformat__ = 'restructuredtext'
 
 import os, sys
@@ -27,12 +27,16 @@ if __name__ == '__main__':
     execfile(os.path.join(sys.path[0], 'framework.py'))
 
 from Testing import ZopeTestCase # side effect import. leave it here.
-from Products.ATContentTypes.tests import atcttestcase
+from Products.ATContentTypes.tests import atcttestcase, atctftestcase
 from Products.ATContentTypes.config import TOOLNAME
 from Products.ATContentTypes.interfaces import IATCTTool
 from Interface.Verify import verifyObject
 from Products.CMFCore.utils import getToolByName
 
+# z3 imports
+from Products.ATContentTypes.interface import IATCTTool as Z3IATCTTool
+from zope.interface.verify import verifyObject as Z3verifyObject
+
 tests = []
 
 class TestTool(atcttestcase.ATCTSiteTestCase):
@@ -176,6 +180,11 @@ class TestTool(atcttestcase.ATCTSiteTestCase):
         t = self.tool
         self.failUnless(IATCTTool.isImplementedBy(t))
         self.failUnless(verifyObject(IATCTTool, t))
+
+    def test_Z3interface(self):
+        t = self.tool
+        iface = Z3IATCTTool
+        self.failUnless(Z3verifyObject(iface, t))
         
     def test_names(self):
         t = self.tool
@@ -244,6 +253,27 @@ class TestTool(atcttestcase.ATCTSiteTestCase):
 
 tests.append(TestTool)
 
+class TestATCTToolFunctional(atctftestcase.IntegrationTestCase):
+    
+    zmi_tabs = ('manage_imageScales', 'manage_recatalog', 'manage_versionMigration',
+                'manage_overview', 'manage_typeMigration',
+               )
+    
+    def setupTestObject(self):
+        self.obj_id = TOOLNAME
+        self.obj = getToolByName(self.portal, TOOLNAME)
+        self.obj_url = self.obj.absolute_url()
+        self.obj_path = '/%s' % self.obj.absolute_url(1)
+
+    def test_zmi_tabs(self):
+        for view in self.zmi_tabs:
+            response = self.publish('%s/%s' % (self.obj_path, view), self.owner_auth)
+            self.assertStatusEqual(response.getStatus(), 200, 
+                "%s: %s" % (view, response.getStatus())) # OK
+
+tests.append(TestATCTToolFunctional)
+
+
 if __name__ == '__main__':
     framework()
 else:
